@@ -1,15 +1,19 @@
-import fcntl
 import functools
 import glob
 import operator
 import os
+import platform
 import subprocess
 import time
 from typing import List, Optional, Union
 
+if platform.system() == 'Linux':
+    import fcntl
+
+import warnings
+
 from . import filter_monitors, get_methods
 from .helpers import EDID, __cache__, _monitor_brand_lookup
-import warnings
 
 
 class SysFiles:
@@ -90,12 +94,13 @@ class SysFiles:
                         # to 'actual' values
                         continue
 
-                device.update(
-                    zip(
-                        ('manufacturer_id', 'manufacturer', 'model', 'name', 'serial'),
-                        EDID.parse(device['edid'])
-                    )
-                )
+                for key, value in zip(
+                    ('manufacturer_id', 'manufacturer', 'model', 'name', 'serial'),
+                    EDID.parse(device['edid'])
+                ):
+                    if value is None:
+                        continue
+                    device[key] = value
 
                 displays[device['edid']] = device
                 index += 1
@@ -795,12 +800,13 @@ class XRandr:
                 )
                 tmp_display['edid'] = edid
 
-                tmp_display.update(
-                    zip(
-                        ('manufacturer_id', 'manufacturer', 'model', 'name', 'serial'),
-                        EDID.parse(edid)
-                    )
-                )
+                for key, value in zip(
+                    ('manufacturer_id', 'manufacturer', 'model', 'name', 'serial'),
+                    EDID.parse(tmp_display['edid'])
+                ):
+                    if value is None:
+                        continue
+                    tmp_display[key] = value
 
             elif 'Brightness:' in line and brightness:
                 tmp_display['brightness'] = int(float(line.replace('Brightness:', '')) * 100)
