@@ -1,4 +1,5 @@
 import ctypes
+import platform
 import threading
 import time
 from ctypes import POINTER, WINFUNCTYPE, Structure, WinError, byref, windll
@@ -11,7 +12,8 @@ import win32api
 import win32con
 import wmi
 
-from . import EDID, __cache__, _monitor_brand_lookup, filter_monitors, platform
+from . import filter_monitors, get_methods
+from .helpers import EDID, __cache__, _monitor_brand_lookup
 
 # a bunch of typing classes were deprecated in Python 3.9
 # in favour of collections.abc (https://www.python.org/dev/peps/pep-0585/)
@@ -212,10 +214,7 @@ class WMI:
             benq_info = sbc.windows.WMI.get_display_info('BenQ GL2450H')
             ```
         '''
-        info = __cache__.get('wmi_monitor_info')
-        if info is None:
-            info = [i for i in get_display_info() if i['method'] == cls]
-            __cache__.store('wmi_monitor_info', info)
+        info = [i for i in get_display_info() if i['method'] == cls]
         if display is not None:
             info = filter_monitors(display=display, haystack=info)
         return info
@@ -392,10 +391,7 @@ class VCP:
             # EG output: {'name': 'BenQ GL2450H', 'model': 'GL2450H', ... }
             ```
         '''
-        info = __cache__.get('vcp_monitor_info')
-        if info is None:
-            info = [i for i in get_display_info() if i['method'] == cls]
-            __cache__.store('vcp_monitor_info', info)
+        info = [i for i in get_display_info() if i['method'] == cls]
         if display is not None:
             info = filter_monitors(display=display, haystack=info)
         return info
@@ -500,7 +496,8 @@ def list_monitors_info(method: Optional[str] = None, allow_duplicates: bool = Fa
     Lists detailed information about all detected monitors
 
     Args:
-        method (str): the method the monitor can be addressed by. Can be 'wmi' or 'vcp'
+        method (str): the method the monitor can be addressed by. See `screen_brightness_control.get_methods`
+            for more info on available methods
         allow_duplicates (bool): whether to filter out duplicate displays (displays with the same EDID) or not
 
     Returns:
@@ -534,23 +531,23 @@ def list_monitors_info(method: Optional[str] = None, allow_duplicates: bool = Fa
             print('EDID:', info['edid'])
         ```
     '''
-    info = __cache__.get(f'windows_monitors_info_{method}_{allow_duplicates}')
-    if info is None:
-        info = get_display_info()
+    # no caching here because get_display_info caches its results
+    info = get_display_info()
 
-        if method is not None:
-            method = method.lower()
-            if method not in ('wmi', 'vcp'):
-                raise ValueError('method kwarg must be "wmi" or "vcp"')
+    all_methods = get_methods()
 
-        info_final = []
-        serials = []
-        # to make sure each display (with unique edid) is only reported once
-        for i in info:
-            if allow_duplicates or i['serial'] not in serials:
-                if method is None or method == i['method'].__name__.lower():
-                    serials.append(i['serial'])
-                    info_final.append(i)
-        __cache__.store(f'windows_monitors_info_{method}_{allow_duplicates}', info_final)
-        info = info_final
-    return info
+    if method is not None:
+        method = method.lower()
+        if method not in all_methods:
+            raise ValueError(f'method must be one of: {list(all_methods)}')
+
+    info_final = []
+    serials = []
+    # to make sure each display (with unique edid) is only reported once
+    for i in info:
+        if allow_duplicates or i['serial'] not in serials:
+            if method is None or method == i['method'].__name__.lower():
+                serials.append(i['serial'])
+                info_final.append(i)
+
+    return info_final
